@@ -20,6 +20,6 @@ class StatsClient(StatsClient):
         """Decrement a stat by `count`."""
         log.info('Decrement: %s, %s, %s' % (stat, count, rate))
 
-    def gauge(self, stat, value, rate=1):
+    def gauge(self, stat, value, rate=1, delta=False):
         """Set a gauge value."""
-        log.info('Gauge: %s, %s, %s' % (stat, value, rate))
+        log.info('Gauge: %s, %s%s, %s' % (stat, '' if not delta else 'diff ', value , rate))
