@@ -1,8 +1,10 @@
-from django.http import Http404
-from django_statsd.clients import statsd
 import inspect
 import time
 
+from django.http import Http404
+
+from django_statsd.clients import statsd
+
 
 class GraphiteMiddleware(object):
 
@@ -59,5 +61,5 @@ class TastyPieRequestTimingMiddleware(GraphiteRequestTimingMiddleware):
             request._view_name = view_kwargs['resource_name']
             request._start_time = time.time()
         except (AttributeError, KeyError):
-            super(TastyPieRequestTimingMiddleware, self).process_view(request,
-                view_func, view_args, view_kwargs)
+            super(TastyPieRequestTimingMiddleware, self).process_view(
+                request, view_func, view_args, view_kwargs)
