@@ -1,3 +1,5 @@
+from collections import defaultdict
+
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _, ungettext
 
@@ -43,6 +45,35 @@ def times(stats):
                         duration_ratio_relative * 100.0,
                         duration,
                         ])
+    results.sort(key=lambda r: r[1])
+    return results
+
+
+def times_summary(stats):
+    results = []
+    if not stats:
+        return results
+
+    timings = defaultdict(list)
+    for stat in stats:
+        timings[stat[0].split('|')[0]].append(stat[2])
+
+    for stat, v in timings.iteritems():
+        if not v:
+            continue
+        v.sort()
+        count = len(v)
+        vmin, vmax = v[0], v[-1]
+        vsum = sum(v)
+        mean = vsum / float(count)
+        results.append({
+            'stat': stat,
+            'count': count,
+            'sum': vsum,
+            'lower': vmin,
+            'upper': vmax,
+            'mean': mean,
+            })
     return results
 
 
@@ -76,5 +107,6 @@ class StatsdPanel(Panel):
         self.record_stats({
             'graphite': config.get('graphite'),
             'statsd': munge(self.statsd.cache),
-            'timings': times(self.statsd.timings)
+            'timings': times(self.statsd.timings),
+            'timings_summary': times_summary(self.statsd.timings),
         })
