@@ -3,7 +3,8 @@ try:
 except ImportError: # django < 1.4
     from django.conf.urls.defaults import patterns, url
 
-urlpatterns = patterns('',
-    url('^record$', 'django_statsd.views.record',
-        name='django_statsd.record'),
+
+urlpatterns = patterns(
+    '',
+    url('^record$', 'django_statsd.views.record', name='django_statsd.record'),
 )
