@@ -1,3 +1,4 @@
+import collections
 from django import http
 from django.conf import settings
 from django.views.decorators.csrf import csrf_exempt
@@ -5,46 +6,47 @@ from django.views.decorators.http import require_http_methods
 
 from django_statsd.clients import statsd
 
+
 boomerang = {
- 'window.performance.navigation.redirectCount': 'nt_red_cnt',
- 'window.performance.navigation.type': 'nt_nav_type',
- 'window.performance.timing.connectEnd': 'nt_con_end',
- 'window.performance.timing.connectStart': 'nt_con_st',
- 'window.performance.timing.domComplete': 'nt_domcomp',
- 'window.performance.timing.domContentLoaded': 'nt_domcontloaded',
- 'window.performance.timing.domInteractive': 'nt_domint',
- 'window.performance.timing.domLoading': 'nt_domloading',
- 'window.performance.timing.domainLookupEnd': 'nt_dns_end',
- 'window.performance.timing.domainLookupStart': 'nt_dns_st',
- 'window.performance.timing.fetchStart': 'nt_fet_st',
- 'window.performance.timing.loadEventEnd': 'nt_load_end',
- 'window.performance.timing.loadEventStart': 'nt_load_st',
- 'window.performance.timing.navigationStart': 'nt_nav_st',
- 'window.performance.timing.redirectEnd': 'nt_red_end',
- 'window.performance.timing.redirectStart': 'nt_red_st',
- 'window.performance.timing.requestStart': 'nt_req_st',
- 'window.performance.timing.responseEnd': 'nt_res_end',
- 'window.performance.timing.responseStart': 'nt_res_st',
- 'window.performance.timing.unloadEventEnd': 'nt_unload_end',
- 'window.performance.timing.unloadEventStart': 'nt_unload_st'
+    'window.performance.navigation.redirectCount': 'nt_red_cnt',
+    'window.performance.navigation.type': 'nt_nav_type',
+    'window.performance.timing.connectEnd': 'nt_con_end',
+    'window.performance.timing.connectStart': 'nt_con_st',
+    'window.performance.timing.domComplete': 'nt_domcomp',
+    'window.performance.timing.domContentLoaded': 'nt_domcontloaded',
+    'window.performance.timing.domInteractive': 'nt_domint',
+    'window.performance.timing.domLoading': 'nt_domloading',
+    'window.performance.timing.domainLookupEnd': 'nt_dns_end',
+    'window.performance.timing.domainLookupStart': 'nt_dns_st',
+    'window.performance.timing.fetchStart': 'nt_fet_st',
+    'window.performance.timing.loadEventEnd': 'nt_load_end',
+    'window.performance.timing.loadEventStart': 'nt_load_st',
+    'window.performance.timing.navigationStart': 'nt_nav_st',
+    'window.performance.timing.redirectEnd': 'nt_red_end',
+    'window.performance.timing.redirectStart': 'nt_red_st',
+    'window.performance.timing.requestStart': 'nt_req_st',
+    'window.performance.timing.responseEnd': 'nt_res_end',
+    'window.performance.timing.responseStart': 'nt_res_st',
+    'window.performance.timing.unloadEventEnd': 'nt_unload_end',
+    'window.performance.timing.unloadEventStart': 'nt_unload_st'
 }
 
 types = {
- '0': 'navigate',
- '1': 'reload',
- '2': 'back_forward',
- '255': 'reserved'
+    '0': 'navigate',
+    '1': 'reload',
+    '2': 'back_forward',
+    '255': 'reserved'
 }
 
 # These are the default keys that we will try and record.
 stick_keys = [
- 'window.performance.timing.domComplete',
- 'window.performance.timing.domInteractive',
- 'window.performance.timing.domLoading',
- 'window.performance.timing.loadEventEnd',
- 'window.performance.timing.responseStart',
- 'window.performance.navigation.redirectCount',
- 'window.performance.navigation.type',
+    'window.performance.timing.domComplete',
+    'window.performance.timing.domInteractive',
+    'window.performance.timing.domLoading',
+    'window.performance.timing.loadEventEnd',
+    'window.performance.timing.responseStart',
+    'window.performance.navigation.redirectCount',
+    'window.performance.navigation.type',
 ]
 
 
@@ -63,14 +65,14 @@ def process_key(start, key, value):
 def _process_summaries(start, keys):
     calculated = {
         'network': keys['window.performance.timing.responseStart'] - start,
-        'app': keys['window.performance.timing.domLoading'] -
-               keys['window.performance.timing.responseStart'],
-        'dom': keys['window.performance.timing.domComplete'] -
-               keys['window.performance.timing.domLoading'],
-        'rendering': keys['window.performance.timing.loadEventEnd'] -
-                     keys['window.performance.timing.domComplete'],
+        'app': (keys['window.performance.timing.domLoading'] -
+                keys['window.performance.timing.responseStart']),
+        'dom': (keys['window.performance.timing.domComplete'] -
+                keys['window.performance.timing.domLoading']),
+        'rendering': (keys['window.performance.timing.loadEventEnd'] -
+                      keys['window.performance.timing.domComplete']),
     }
-    for k, v in calculated.items():
+    for k, v in list(calculated.items()):
         # If loadEventEnd still does not get populated, we could end up with
         # negative numbers here.
         statsd.timing('window.performance.calculated.%s' % k, max(v, 0))
@@ -79,7 +81,8 @@ def _process_summaries(start, keys):
 @require_http_methods(['GET', 'HEAD'])
 def _process_boomerang(request):
     if 'nt_nav_st' not in request.GET:
-        raise ValueError('nt_nav_st not in request.GET, make sure boomerang'
+        raise ValueError(
+            'nt_nav_st not in request.GET, make sure boomerang'
             ' is made with navigation API timings as per the following'
             ' http://yahoo.github.com/boomerang/doc/howtos/howto-9.html')
 
@@ -126,8 +129,8 @@ def _process_stick(request):
 
 
 clients = {
- 'boomerang': _process_boomerang,
- 'stick': _process_stick,
+    'boomerang': _process_boomerang,
+    'stick': _process_stick,
 }
 
 
@@ -152,7 +155,7 @@ def record(request):
 
     guard = getattr(settings, 'STATSD_RECORD_GUARD', None)
     if guard:
-        if not callable(guard):
+        if not isinstance(guard, collections.Callable):
             raise ValueError('STATSD_RECORD_GUARD must be callable')
         result = guard(request)
         if result:
